@@ -6,4 +6,10 @@ set -x
 export http_proxy=127.0.0.1:9
 export https_proxy=127.0.0.1:9
 
-pex -m textwrap -vv -o script && ./script
+pex --python=python3 -m textwrap -vv -o script && ./script
+
+if [ $? -eq 0 ]; then
+    echo 9
+fi
+
+echo -1
